.. _glossary:

Glossary
********

.. glossary::

    adjacency
        Square matrix whose entries indicate edges between nodes of a graph, usually denoted by :math:`A`.

    biadjacency
        Rectangular matrix whose entries indicate edges between nodes of a bipartite graph,
        usually denoted by :math:`B`.

    co-neighbors
        Graph defined by :math:`\tilde{A} = AF^{-1}A^T`, or :math:`\tilde{B} = BF^{-1}B^T`,
        where :math:`F` is a weight matrix.

    degree
        For an unweighted, undirected graph, the degree of a node is defined as its number of neighbors.

    embedding
        Mapping of the nodes of a graph to points in a vector space.

    graph
        Mathematical object :math:`G = (V, E)`, where :math:`V` is the set of vertices or nodes
        and :math:`E \in V \times V` the set of edges.
